@@ -27,7 +27,8 @@ $this->includeJsFile('administration.housekeeping.edit.js.php');
 
 $widget = (new CWidget())
 	->setTitle(_('Housekeeping'))
-	->setTitleSubmenu(getAdministrationGeneralSubmenu());
+	->setTitleSubmenu(getAdministrationGeneralSubmenu())
+	->setDocUrl(CDocHelper::getUrl(CDocHelper::ADMINISTRATION_HOUSEKEEPING_EDIT));
 
 $form = (new CForm())
 	->setId('housekeeping')
@@ -54,6 +55,15 @@ $house_keeper_tab = (new CFormList())
 			->setEnabled($data['hk_events_mode'] == 1)
 			->setAriaRequired()
 	)
+	->addRow(
+		(new CLabel(_('Service data storage period'), 'hk_events_service'))->setAsteriskMark(),
+		(new CTextBox('hk_events_service', $data['hk_events_service'], false,
+			DB::getFieldLength('config', 'hk_events_service')
+		))
+			->setWidth(ZBX_TEXTAREA_TINY_WIDTH)
+			->setEnabled($data['hk_events_mode'] == 1)
+			->setAriaRequired()
+	)
 	->addRow(
 		(new CLabel(_('Internal data storage period'), 'hk_events_internal'))->setAsteriskMark(),
 		(new CTextBox('hk_events_internal', $data['hk_events_internal'], false,
@@ -96,19 +106,6 @@ $house_keeper_tab = (new CFormList())
 			->setEnabled($data['hk_services_mode'] == 1)
 			->setAriaRequired()
 	)
-	->addRow((new CTag('h4', true, _('Audit')))->addClass('input-section-header'))
-	->addRow(
-		new CLabel(_('Enable internal housekeeping'), 'hk_audit_mode'),
-		(new CCheckBox('hk_audit_mode'))->setChecked($data['hk_audit_mode'] == 1)
-	)
-	->addRow(
-		(new CLabel(_('Data storage period'), 'hk_audit'))
-			->setAsteriskMark(),
-		(new CTextBox('hk_audit', $data['hk_audit'], false, DB::getFieldLength('config', 'hk_audit')))
-			->setWidth(ZBX_TEXTAREA_TINY_WIDTH)
-			->setEnabled($data['hk_audit_mode'] == 1)
-			->setAriaRequired()
-	)
 	->addRow((new CTag('h4', true, _('User sessions')))->addClass('input-section-header'))
 	->addRow(
 		new CLabel(_('Enable internal housekeeping'), 'hk_sessions_mode'),
@@ -177,13 +174,21 @@ $house_keeper_tab = (new CFormList())
 			);
 	}
 
-$house_keeper_view = (new CTabView())
-	->addTab('houseKeeper', _('Housekeeping'), $house_keeper_tab)
-	->setFooter(makeFormFooter(
-		new CSubmit('update', _('Update')),
-		[new CButton('resetDefaults', _('Reset defaults'))]
-	));
+
+$house_keeper_tab
+	->addRow((new CTag('h4', true, _('Audit')))->addClass('input-section-header'))
+	->addRow(new CLink(_('Audit settings'), (new CUrl('zabbix.php'))->setArgument('action', 'audit.settings.edit'))
+);
+
+$form->addItem(
+	(new CTabView())
+		->addTab('houseKeeper', _('Housekeeping'), $house_keeper_tab)
+		->setFooter(makeFormFooter(
+			new CSubmit('update', _('Update')),
+			[new CButton('resetDefaults', _('Reset defaults'))]
+		))
+);
 
 $widget
-	->addItem($form->addItem($house_keeper_view))
+	->addItem($form)
 	->show();
