@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2020 Zabbix SIA
+** Copyright (C) 2001-2022 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -19,6 +19,10 @@
 **/
 
 
+/**
+ * @var CView $this
+ */
+
 // indicator of sort field
 $sort_div = (new CSpan())
 	->addClass(($data['sortorder'] === ZBX_SORT_DOWN) ? ZBX_STYLE_ARROW_DOWN : ZBX_STYLE_ARROW_UP);
@@ -49,24 +53,35 @@ foreach ($data['alerts'] as $alert) {
 		$info_icons = null;
 	}
 
+	$message = ($alert['alerttype'] == ALERT_TYPE_MESSAGE)
+		? [
+			bold($alert['subject']),
+			BR(),
+			BR(),
+			zbx_nl2br($alert['message'])
+		]
+		: [
+			zbx_nl2br($alert['message'])
+		];
+
 	$table->addRow([
 		zbx_date2str(DATE_TIME_FORMAT_SECONDS, $alert['clock']),
 		array_key_exists($alert['actionid'], $data['actions']) ? $data['actions'][$alert['actionid']]['name'] : '',
 		$alert['description'],
 		makeEventDetailsTableUser($alert, $data['db_users']),
-		[bold($alert['subject']), BR(), BR(), zbx_nl2br($alert['message'])],
+		$message,
 		makeActionTableStatus($alert),
 		makeInformationList($info_icons)
 	]);
 }
 
 $output = [
-	'header' => $data['name'],
+	'name' => $data['name'],
 	'body' => $table->toString()
 ];
 
-if (($messages = getMessages()) !== null) {
-	$output['messages'] = $messages->toString();
+if ($messages = get_and_clear_messages()) {
+	$output['messages'] = array_column($messages, 'message');
 }
 
 if ($data['user']['debug_mode'] == GROUP_DEBUG_MODE_ENABLED) {
@@ -74,4 +89,4 @@ if ($data['user']['debug_mode'] == GROUP_DEBUG_MODE_ENABLED) {
 	$output['debug'] = CProfiler::getInstance()->make()->toString();
 }
 
-echo (new CJson())->encode($output);
+echo json_encode($output);
