@@ -37,10 +37,10 @@ else {
 
 		foreach ($data['items'] as $item) {
 			$table_header[] = (new CColHeader(
-				($data['same_host'] ? '' : $item['hosts'][0]['name'].NAME_DELIMITER).$item['name_expanded']
+				($data['same_host'] ? '' : $item['hosts'][0]['name'].NAME_DELIMITER).$item['name']
 			))
 				->addClass('vertical_rotation')
-				->setTitle($item['name_expanded']);
+				->setTitle($item['name']);
 		}
 	}
 	else {
@@ -66,7 +66,7 @@ else {
 				$table_row[] = ($data['same_host']
 					? ''
 					: $data['items'][$history_item['itemid']]['hosts'][0]['name'].NAME_DELIMITER).
-					$data['items'][$history_item['itemid']]['name_expanded'];
+					$data['items'][$history_item['itemid']]['name'];
 			}
 			$table_row[] = $history_item['value'];
 			$table->addRow($table_row);
@@ -101,6 +101,10 @@ $output = [
 	'body' => $table->toString()
 ];
 
+if ($messages = get_and_clear_messages()) {
+	$output['messages'] = array_column($messages, 'message');
+}
+
 if ($data['user']['debug_mode'] == GROUP_DEBUG_MODE_ENABLED) {
 	CProfiler::getInstance()->stop();
 	$output['debug'] = CProfiler::getInstance()->make()->toString();
