@@ -80,6 +80,8 @@ class CGraph extends CGraphGeneral {
 			// output
 			'output'					=> API_OUTPUT_EXTEND,
 			'selectGroups'				=> null,
+			'selectHostGroups'			=> null,
+			'selectTemplateGroups'		=> null,
 			'selectTemplates'			=> null,
 			'selectHosts'				=> null,
 			'selectItems'				=> null,
@@ -95,6 +97,8 @@ class CGraph extends CGraphGeneral {
 		];
 		$options = zbx_array_merge($defOptions, $options);
 
+		$this->checkDeprecatedParam($options, 'selectGroups');
+
 		// permission check
 		if (self::$userData['type'] != USER_TYPE_SUPER_ADMIN && !$options['nopermissions']) {
 			$permission = $options['editable'] ? PERM_READ_WRITE : PERM_READ;
@@ -337,7 +341,7 @@ class CGraph extends CGraphGeneral {
 
 		CGraphManager::delete($graphids);
 
-		$this->addAuditBulk(AUDIT_ACTION_DELETE, AUDIT_RESOURCE_GRAPH, $db_graphs);
+		$this->addAuditBulk(CAudit::ACTION_DELETE, CAudit::RESOURCE_GRAPH, $db_graphs);
 
 		return ['graphids' => $graphids];
 	}
