@@ -35,7 +35,7 @@ abstract class CHostGeneral extends CHostBase {
 	];
 
 	/**
-	 * Check for valid host groups.
+	 * Check for valid host groups and template groups.
 	 *
 	 * @param array      $hosts
 	 * @param array|null $db_hosts
@@ -71,7 +71,8 @@ abstract class CHostGeneral extends CHostBase {
 			return;
 		}
 
-		$count = API::HostGroup()->get([
+		$entity = $this instanceof CTemplate ? API::TemplateGroup() : API::HostGroup();
+		$count = $entity->get([
 			'countOutput' => true,
 			'groupids' => array_keys($edit_groupids),
 			'editable' => true
@@ -1373,37 +1374,103 @@ abstract class CHostGeneral extends CHostBase {
 
 		$hostids = array_keys($result);
 
-		// adding groups
-		if ($options['selectGroups'] !== null && $options['selectGroups'] != API_OUTPUT_COUNT) {
-			$relationMap = $this->createRelationMap($result, 'hostid', 'groupid', 'hosts_groups');
-			$groups = API::HostGroup()->get([
-				'output' => $options['selectGroups'],
-				'groupids' => $relationMap->getRelatedIds(),
-				'preservekeys' => true
-			]);
-			$result = $relationMap->mapMany($result, $groups, 'groups');
-		}
-
-		// adding templates
+		// Add templates.
 		if ($options['selectParentTemplates'] !== null) {
 			if ($options['selectParentTemplates'] != API_OUTPUT_COUNT) {
 				$templates = [];
-				$relationMap = $this->createRelationMap($result, 'hostid', 'templateid', 'hosts_templates');
-				$related_ids = $relationMap->getRelatedIds();
 
-				if ($related_ids) {
+				// Get template IDs for each host and additional field from relation table if necessary.
+				$hosts_templates = DBfetchArray(DBselect(
+					'SELECT ht.hostid,ht.templateid'.
+						($this->outputIsRequested('link_type', $options['selectParentTemplates'])
+							? ',ht.link_type'
+							: ''
+						).
+					' FROM hosts_templates ht'.
+					' WHERE '.dbConditionId('ht.hostid', array_keys($result))
+				));
+
+				if ($hosts_templates) {
+					// Select also template ID if not selected. It can be removed from results if not requested.
+					$template_options = $this->outputIsRequested('templateid', $options['selectParentTemplates'])
+						? $options['selectParentTemplates']
+						: array_merge($options['selectParentTemplates'], ['templateid']);
+
+					/*
+					 * Since templates API does not have "link_type" field, remove it from request, so that template.get
+					 * validation may pass successfully.
+					 */
+					if ($this->outputIsRequested('link_type', $template_options) && is_array($template_options)
+							&& ($key = array_search('link_type', $template_options)) !== false) {
+						unset($template_options[$key]);
+					}
+
 					$templates = API::Template()->get([
-						'output' => $options['selectParentTemplates'],
-						'templateids' => $related_ids,
+						'output' => $template_options,
+						'templateids' => array_column($hosts_templates, 'templateid'),
 						'nopermissions' => $options['nopermissions'],
 						'preservekeys' => true
 					]);
-					if (!is_null($options['limitSelects'])) {
+
+					if ($options['limitSelects'] !== null) {
 						order_result($templates, 'host');
 					}
 				}
 
-				$result = $relationMap->mapMany($result, $templates, 'parentTemplates', $options['limitSelects']);
+				/*
+				 * In order to correctly slice the ordered templates in case of "limitSelects", first they must be
+				 * mapped for each host. Otherwise incorrect results may appear. $relation_map key is the host ID, and
+				 * values are template ID and, if selected, "link_type".
+				 */
+				$relation_map = [];
+				foreach ($hosts_templates as $host_template) {
+					if (!array_key_exists($host_template['hostid'], $relation_map)) {
+						$relation_map[$host_template['hostid']] = [];
+					}
+
+					$related_fields = ['templateid' => $host_template['templateid']];
+
+					if ($this->outputIsRequested('link_type', $options['selectParentTemplates'])) {
+						$related_fields['link_type'] = $host_template['link_type'];
+					}
+
+					$relation_map[$host_template['hostid']][] = $related_fields;
+				}
+
+				foreach ($result as $hostid => &$host) {
+					$host['parentTemplates'] = [];
+
+					if (array_key_exists($hostid, $relation_map)) {
+						$templateids = array_column($relation_map[$hostid], 'templateid');
+						$templateids = array_combine($templateids, $templateids);
+
+						// Find the matching templates and limit the results if necessary.
+						$host['parentTemplates'] = array_values(array_intersect_key($templates, $templateids));
+
+						if ($options['limitSelects'] !== null && $options['limitSelects'] != 0) {
+							$host['parentTemplates'] = array_slice($host['parentTemplates'], 0,
+								$options['limitSelects']
+							);
+						}
+
+						// Append the additional field from relation table.
+						if ($this->outputIsRequested('link_type', $options['selectParentTemplates'])) {
+							foreach ($host['parentTemplates'] as &$template) {
+								foreach ($relation_map[$hostid] as $rel_template) {
+									if (bccomp($template['templateid'], $rel_template['templateid']) == 0) {
+										$template['link_type'] = $rel_template['link_type'];
+									}
+								}
+							}
+						}
+
+						// Unset fields if they were not requested.
+						$host['parentTemplates'] = $this->unsetExtraFields($host['parentTemplates'], ['templateid'],
+							$options['selectParentTemplates']
+						);
+					}
+				}
+				unset($host);
 			}
 			else {
 				$templates = API::Template()->get([
@@ -1420,7 +1487,6 @@ abstract class CHostGeneral extends CHostBase {
 			}
 		}
 
-		// adding items
 		if ($options['selectItems'] !== null) {
 			if ($options['selectItems'] != API_OUTPUT_COUNT) {
 				$items = API::Item()->get([
@@ -1453,7 +1519,6 @@ abstract class CHostGeneral extends CHostBase {
 			}
 		}
 
-		// adding discoveries
 		if ($options['selectDiscoveries'] !== null) {
 			if ($options['selectDiscoveries'] != API_OUTPUT_COUNT) {
 				$items = API::DiscoveryRule()->get([
@@ -1488,7 +1553,6 @@ abstract class CHostGeneral extends CHostBase {
 			}
 		}
 
-		// adding triggers
 		if ($options['selectTriggers'] !== null) {
 			if ($options['selectTriggers'] != API_OUTPUT_COUNT) {
 				$triggers = [];
@@ -1535,7 +1599,6 @@ abstract class CHostGeneral extends CHostBase {
 			}
 		}
 
-		// adding graphs
 		if ($options['selectGraphs'] !== null) {
 			if ($options['selectGraphs'] != API_OUTPUT_COUNT) {
 				$graphs = [];
@@ -1581,7 +1644,6 @@ abstract class CHostGeneral extends CHostBase {
 			}
 		}
 
-		// adding http tests
 		if ($options['selectHttpTests'] !== null) {
 			if ($options['selectHttpTests'] != API_OUTPUT_COUNT) {
 				$httpTests = API::HttpTest()->get([
@@ -1616,32 +1678,6 @@ abstract class CHostGeneral extends CHostBase {
 			}
 		}
 
-		// adding tags
-		if ($options['selectTags'] !== null && $options['selectTags'] != API_OUTPUT_COUNT) {
-			if ($options['selectTags'] === API_OUTPUT_EXTEND) {
-				$options['selectTags'] = ['tag', 'value'];
-			}
-
-			$tags_options = [
-				'output' => $this->outputExtend($options['selectTags'], ['hostid']),
-				'filter' => ['hostid' => $hostids]
-			];
-
-			foreach ($result as &$host) {
-				$host['tags'] = [];
-			}
-			unset($host);
-
-			$tags = DBselect(DB::makeSql('host_tag', $tags_options));
-
-			while ($tag = DBfetch($tags)) {
-				$hostid = $tag['hostid'];
-				unset($tag['hosttagid'], $tag['hostid']);
-				$result[$hostid]['tags'][] = $tag;
-			}
-		}
-
-		// Add value mapping.
 		if ($options['selectValueMaps'] !== null) {
 			if ($options['selectValueMaps'] === API_OUTPUT_EXTEND) {
 				$options['selectValueMaps'] = ['valuemapid', 'name', 'mappings'];
@@ -1688,35 +1724,7 @@ abstract class CHostGeneral extends CHostBase {
 	}
 
 	/**
-	 * Validates tags.
-	 *
-	 * @param array  $host
-	 * @param int    $host['evaltype']
-	 * @param array  $host['tags']
-	 * @param string $host['tags'][]['tag']
-	 * @param string $host['tags'][]['value']
-	 *
-	 * @throws APIException if the input is invalid.
-	 */
-	protected function validateTags(array $host) {
-		$api_input_rules = ['type' => API_OBJECT, 'fields' => [
-			'evaltype'	=> ['type' => API_INT32, 'in' => implode(',', [TAG_EVAL_TYPE_AND_OR, TAG_EVAL_TYPE_OR])],
-			'tags'		=> ['type' => API_OBJECTS, 'flags' => API_NORMALIZE, 'uniq' => [['tag', 'value']], 'fields' => [
-				'tag'		=> ['type' => API_STRING_UTF8, 'flags' => API_REQUIRED | API_NOT_EMPTY, 'length' => DB::getFieldLength('host_tag', 'tag')],
-				'value'		=> ['type' => API_STRING_UTF8, 'length' => DB::getFieldLength('host_tag', 'value'), 'default' => DB::getDefault('host_tag', 'value')]
-			]]
-		]];
-
-		// Keep values only for fields with defined validation rules.
-		$host = array_intersect_key($host, $api_input_rules['fields']);
-
-		if (!CApiInputValidator::validate($api_input_rules, $host, '/', $error)) {
-			self::exception(ZBX_API_ERROR_PARAMETERS, $error);
-		}
-	}
-
-	/**
-	 * Add the existing host groups, templates, tags, macros.
+	 * Add the existing host or template groups, templates, tags, macros.
 	 *
 	 * @param array $hosts
 	 * @param array $db_hosts
@@ -1749,11 +1757,20 @@ abstract class CHostGeneral extends CHostBase {
 		$filter = ['hostid' => $hostids];
 
 		if (self::$userData['type'] == USER_TYPE_ZABBIX_ADMIN) {
-			$db_groups = API::HostGroup()->get([
-				'output' => [],
-				$id_field_name.'s' => $hostids,
-				'preservekeys' => true
-			]);
+			if ($this instanceof CTemplate) {
+				$db_groups = API::TemplateGroup()->get([
+					'output' => [],
+					'templateids' => $hostids,
+					'preservekeys' => true
+				]);
+			}
+			else {
+				$db_groups = API::HostGroup()->get([
+					'output' => [],
+					'hostids' => $hostids,
+					'preservekeys' => true
+				]);
+			}
 
 			$filter += ['groupid' => array_keys($db_groups)];
 		}
@@ -1792,11 +1809,20 @@ abstract class CHostGeneral extends CHostBase {
 				$filter += ['groupid' => $objectids];
 			}
 			elseif (self::$userData['type'] == USER_TYPE_ZABBIX_ADMIN) {
-				$db_groups = API::HostGroup()->get([
-					'output' => [],
-					$id_field_name.'s' => array_keys($db_hosts),
-					'preservekeys' => true
-				]);
+				if ($this instanceof CTemplate) {
+					$db_groups = API::TemplateGroup()->get([
+						'output' => [],
+						'templateids' => array_keys($db_hosts),
+						'preservekeys' => true
+					]);
+				}
+				else {
+					$db_groups = API::HostGroup()->get([
+						'output' => [],
+						'hostids' => array_keys($db_hosts),
+						'preservekeys' => true
+					]);
+				}
 
 				$filter += ['groupid' => array_keys($db_groups)];
 			}
