@@ -1,4 +1,4 @@
-<?php declare(strict_types=1);
+<?php declare(strict_types = 0);
 /*
 ** Zabbix
 ** Copyright (C) 2001-2022 Zabbix SIA
@@ -226,6 +226,22 @@ class CSelect extends CTag {
 	/**
 	 * Convert values in associative array to options object collection.
 	 *
+	 * Example:
+	 *
+	 * CSelect::createOptionsFromArray([
+	 * 	0 => 'Min',
+	 * 	1 => 'Avg',
+	 * 	2 => 'Max'
+	 * ])
+	 *
+	 * or
+	 *
+	 * CSelect::createOptionsFromArray([
+	 * 	0 => ['label' => 'Min', 'disabled' => true],
+	 * 	1 => ['label' => 'Avg', 'disabled' => false],
+	 * 	2 => 'Max'
+	 * ])
+	 *
 	 * @static
 	 *
 	 * @param array $values
@@ -236,7 +252,14 @@ class CSelect extends CTag {
 		$options = [];
 
 		foreach ($values as $value => $label) {
-			$options[] = new CSelectOption($value, (string) $label);
+			$disabled = false;
+
+			if (is_array($label)) {
+				$disabled = $label['disabled'];
+				$label = $label['label'];
+			}
+
+			$options[] = (new CSelectOption($value, (string) $label))->setDisabled($disabled);
 		}
 
 		return $options;
