@@ -18,11 +18,11 @@
 ** Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 **/
 
-define('ZABBIX_VERSION',		'6.0.4');
-define('ZABBIX_API_VERSION',	'6.0.4');
-define('ZABBIX_EXPORT_VERSION',	'6.0');
+define('ZABBIX_VERSION',		'6.2.0');
+define('ZABBIX_API_VERSION',	'6.2.0');
+define('ZABBIX_EXPORT_VERSION',	'6.2');
 
-define('ZABBIX_DB_VERSION',		6000000);
+define('ZABBIX_DB_VERSION',		6020000);
 
 define('DB_VERSION_SUPPORTED',				0);
 define('DB_VERSION_LOWER_THAN_MINIMUM',		1);
@@ -34,8 +34,9 @@ define('DB_VERSION_NOT_SUPPORTED_WARNING',	5);
 define('ZABBIX_COPYRIGHT_FROM',	'2001');
 define('ZABBIX_COPYRIGHT_TO',	'2022');
 
+define('ZBX_DOCUMENTATION_URL', 'https://www.zabbix.com/documentation');
+
 define('ZBX_BCRYPT_COST',		10);
-define('ZBX_MD5_SIZE',			32);
 
 define('ZBX_SESSION_NAME', 'zbx_session'); // Session cookie name for Zabbix front-end.
 
@@ -63,6 +64,8 @@ define('ZBX_GEOMAP_MAX_ZOOM', 30); // Max zoom level for geomap.
 
 define('ZBX_MAX_GRAPHS_PER_PAGE', 20);
 
+define('SUBFILTER_VALUES_PER_GROUP', 1000); // Number of subfilter values per group.
+
 // Date and time format separators must be synced with setSDateFromOuterObj() in class.calendar.js.
 define('ZBX_FULL_DATE_TIME',	'Y-m-d H:i:s'); // Time selector full date and time presentation format.
 define('ZBX_DATE_TIME',			'Y-m-d H:i'); // Time selector date and time without seconds presentation format.
@@ -138,6 +141,8 @@ define('ZBX_AUTH_FORM_ZABBIX',	0);
 define('ZBX_AUTH_FORM_HTTP',	1);
 define('ZBX_AUTH_CASE_INSENSITIVE',	0);
 define('ZBX_AUTH_CASE_SENSITIVE',	1);
+define('ZBX_AUTH_START_TLS_OFF',	0);
+define('ZBX_AUTH_START_TLS_ON',		1);
 
 // password policy
 define('PASSWD_CHECK_CASE', 0x01);
@@ -167,7 +172,8 @@ define('ORACLE_UTF8_CHARSET', 'AL32UTF8');
 define('ORACLE_CESU8_CHARSET', 'UTF8');
 
 define('DB_STORE_CREDS_CONFIG', 0);
-define('DB_STORE_CREDS_VAULT', 1);
+define('DB_STORE_CREDS_VAULT_HASHICORP', 1);
+define('DB_STORE_CREDS_VAULT_CYBERARK',  2);
 
 define('PAGE_TYPE_HTML',				0);
 define('PAGE_TYPE_IMAGE',				1);
@@ -289,6 +295,9 @@ define('EVENT_TYPE_ITEM_NOTSUPPORTED',		0);
 define('EVENT_TYPE_LLDRULE_NOTSUPPORTED',	2);
 define('EVENT_TYPE_TRIGGER_UNKNOWN',		4);
 
+define('ZBX_TAG_MANUAL',	0);
+define('ZBX_TAG_AUTOMATIC',	1);
+
 define('HOST_STATUS_MONITORED',		0);
 define('HOST_STATUS_NOT_MONITORED',	1);
 define('HOST_STATUS_TEMPLATE',		3);
@@ -298,6 +307,9 @@ define('HOST_STATUS_PROXY_PASSIVE',	6);
 define('HOST_DISCOVER',		0);
 define('HOST_NO_DISCOVER',	1);
 
+define('TEMPLATE_LINK_MANUAL',	0);
+define('TEMPLATE_LINK_LLD',		1);
+
 define('HOST_ENCRYPTION_NONE',			1);
 define('HOST_ENCRYPTION_PSK',			2);
 define('HOST_ENCRYPTION_CERTIFICATE',	4);
@@ -315,13 +327,14 @@ define('INTERFACE_PRIMARY',		1);
 define('INTERFACE_USE_DNS',	0);
 define('INTERFACE_USE_IP',	1);
 
-define('INTERFACE_TYPE_OPT',		-2);
-define('INTERFACE_TYPE_ANY',		-1);
-define('INTERFACE_TYPE_UNKNOWN',	0);
-define('INTERFACE_TYPE_AGENT',		1);
-define('INTERFACE_TYPE_SNMP',		2);
-define('INTERFACE_TYPE_IPMI',		3);
-define('INTERFACE_TYPE_JMX',		4);
+define('INTERFACE_TYPE_OPT',			-2);
+define('INTERFACE_TYPE_ANY',			-1);
+define('INTERFACE_TYPE_UNKNOWN',		0);
+define('INTERFACE_TYPE_AGENT',			1);
+define('INTERFACE_TYPE_SNMP',			2);
+define('INTERFACE_TYPE_IPMI',			3);
+define('INTERFACE_TYPE_JMX',			4);
+define('INTERFACE_TYPE_AGENT_ACTIVE',	5);
 
 define('HOST_PROT_INTERFACES_INHERIT',	0);
 define('HOST_PROT_INTERFACES_CUSTOM',	1);
@@ -333,6 +346,9 @@ define('MAINTENANCE_STATUS_ACTIVE',		0);
 define('MAINTENANCE_STATUS_APPROACH',	1);
 define('MAINTENANCE_STATUS_EXPIRED',	2);
 
+define('HOST_GROUP_TYPE_HOST_GROUP', 		0);
+define('HOST_GROUP_TYPE_TEMPLATE_GROUP', 	1);
+
 // Modules.
 define('MODULE_STATUS_DISABLED', 0);
 define('MODULE_STATUS_ENABLED',	1);
@@ -912,9 +928,6 @@ define('USER_TYPE_ZABBIX_USER',		1);
 define('USER_TYPE_ZABBIX_ADMIN',	2);
 define('USER_TYPE_SUPER_ADMIN',		3);
 
-define('ZBX_NOT_INTERNAL_GROUP',	0);
-define('ZBX_INTERNAL_GROUP',		1);
-
 define('GROUP_STATUS_DISABLED', 1);
 define('GROUP_STATUS_ENABLED',	0);
 
@@ -1005,12 +1018,17 @@ define('ZBX_ACKNOWLEDGE_PROBLEM',	1);
 define('ZBX_PROBLEM_SUPPRESSED_FALSE',	0);
 define('ZBX_PROBLEM_SUPPRESSED_TRUE',	1);
 
+define('ZBX_PROBLEM_SUPPRESS_TIME_INDEFINITE',	0);
+define('ZBX_PROBLEM_SUPPRESS_TIME_DEFINITE',	1);
+
 define('ZBX_PROBLEM_UPDATE_NONE',			0x00);
 define('ZBX_PROBLEM_UPDATE_CLOSE',			0x01);
 define('ZBX_PROBLEM_UPDATE_ACKNOWLEDGE',	0x02);
 define('ZBX_PROBLEM_UPDATE_MESSAGE',		0x04);
 define('ZBX_PROBLEM_UPDATE_SEVERITY',		0x08);
 define('ZBX_PROBLEM_UPDATE_UNACKNOWLEDGE',	0x10);
+define('ZBX_PROBLEM_UPDATE_SUPPRESS',	    0x20);
+define('ZBX_PROBLEM_UPDATE_UNSUPPRESS',	    0x40);
 
 define('ZBX_EVENT_HISTORY_PROBLEM_EVENT',		0);
 define('ZBX_EVENT_HISTORY_RECOVERY_EVENT',		1);
@@ -1025,8 +1043,13 @@ define('ZBX_TM_TASK_DATA',			7);
 define('ZBX_TM_STATUS_NEW',			1);
 define('ZBX_TM_STATUS_INPROGRESS',	2);
 
-define('ZBX_TM_DATA_TYPE_DIAGINFO',		1);
-define('ZBX_TM_DATA_TYPE_CHECK_NOW',	6);
+define('ZBX_PROTO_VALUE_SUPPRESSION_SUPPRESS', 'suppress');
+define('ZBX_PROTO_VALUE_SUPPRESSION_UNSUPPRESS', 'unsuppress');
+
+define('ZBX_TM_DATA_TYPE_DIAGINFO',			1);
+define('ZBX_TM_DATA_TYPE_PROXY_HOSTIDS',	2);
+define('ZBX_TM_DATA_TYPE_TEMP_SUPPRESSION', 5);
+define('ZBX_TM_DATA_TYPE_CHECK_NOW',		6);
 
 define('EVENT_SOURCE_TRIGGERS',			0);
 define('EVENT_SOURCE_DISCOVERY',		1);
@@ -1072,6 +1095,11 @@ define('AGGREGATE_SUM',		5);
 define('AGGREGATE_FIRST',	6);
 define('AGGREGATE_LAST',	7);
 
+define('APPROXIMATION_MIN',	1);
+define('APPROXIMATION_AVG',	2);
+define('APPROXIMATION_MAX',	4);
+define('APPROXIMATION_ALL',	7);
+
 define('GRAPH_AGGREGATE_BY_ITEM',		0);
 define('GRAPH_AGGREGATE_BY_DATASET',	1);
 
@@ -1102,21 +1130,43 @@ define('SVG_GRAPH_TYPE_POINTS',		1);
 define('SVG_GRAPH_TYPE_STAIRCASE',	2);
 define('SVG_GRAPH_TYPE_BAR',		3);
 
-define('SVG_GRAPH_MISSING_DATA_NONE',			 0);
-define('SVG_GRAPH_MISSING_DATA_CONNECTED',		 1);
-define('SVG_GRAPH_MISSING_DATA_TREAT_AS_ZERO',	 2);
+define('SVG_GRAPH_STACKED_OFF',	0);
+define('SVG_GRAPH_STACKED_ON',	1);
+
+define('SVG_GRAPH_MISSING_DATA_NONE',			0);
+define('SVG_GRAPH_MISSING_DATA_CONNECTED',		1);
+define('SVG_GRAPH_MISSING_DATA_TREAT_AS_ZERO',	2);
+define('SVG_GRAPH_MISSING_DATA_LAST_KNOWN',		3);
 
 define('SVG_GRAPH_DATA_SOURCE_AUTO',	0);
 define('SVG_GRAPH_DATA_SOURCE_HISTORY',	1);
 define('SVG_GRAPH_DATA_SOURCE_TRENDS',	2);
 
-define('SVG_GRAPH_CUSTOM_TIME',	1);
+define('SVG_GRAPH_SIMPLE_TRIGGERS_OFF',	0);
+define('SVG_GRAPH_SIMPLE_TRIGGERS_ON',	1);
 
-define('SVG_GRAPH_LEGEND_TYPE_NONE', 0);
-define('SVG_GRAPH_LEGEND_TYPE_SHORT', 1);
+define('SVG_GRAPH_WORKING_TIME_OFF',	0);
+define('SVG_GRAPH_WORKING_TIME_ON',		1);
 
-define('SVG_GRAPH_LEGEND_LINES_MIN', 1);
-define('SVG_GRAPH_LEGEND_LINES_MAX', 5);
+define('SVG_GRAPH_PERCENTILE_LEFT_OFF',		0);
+define('SVG_GRAPH_PERCENTILE_LEFT_ON',		1);
+
+define('SVG_GRAPH_PERCENTILE_RIGHT_OFF',	0);
+define('SVG_GRAPH_PERCENTILE_RIGHT_ON',		1);
+
+define('SVG_GRAPH_CUSTOM_TIME', 1);
+
+define('SVG_GRAPH_LEGEND_OFF',	0);
+define('SVG_GRAPH_LEGEND_ON',	1);
+
+define('SVG_GRAPH_LEGEND_STATISTIC_OFF',	0);
+define('SVG_GRAPH_LEGEND_STATISTIC_ON',		1);
+
+define('SVG_GRAPH_LEGEND_LINES_MIN',	1);
+define('SVG_GRAPH_LEGEND_LINES_MAX',	10);
+
+define('SVG_GRAPH_LEGEND_COLUMNS_MIN',	1);
+define('SVG_GRAPH_LEGEND_COLUMNS_MAX',	4);
 
 define('SVG_GRAPH_PROBLEMS_SHOW', 1);
 
@@ -1124,15 +1174,15 @@ define('SVG_GRAPH_SELECTED_ITEM_PROBLEMS', 1);
 
 define('SVG_GRAPH_AXIS_SHOW', 1);
 
-define('SVG_GRAPH_AXIS_UNITS_AUTO', 0);
-define('SVG_GRAPH_AXIS_UNITS_STATIC', 1);
+define('SVG_GRAPH_AXIS_UNITS_AUTO',		0);
+define('SVG_GRAPH_AXIS_UNITS_STATIC',	1);
 
 define('SVG_GRAPH_MAX_NUMBER_OF_METRICS', 50);
 
-define('SVG_GRAPH_DEFAULT_WIDTH',         1);
-define('SVG_GRAPH_DEFAULT_POINTSIZE',     3);
-define('SVG_GRAPH_DEFAULT_TRANSPARENCY',  5);
-define('SVG_GRAPH_DEFAULT_FILL',          3);
+define('SVG_GRAPH_DEFAULT_WIDTH',			1);
+define('SVG_GRAPH_DEFAULT_POINTSIZE',		3);
+define('SVG_GRAPH_DEFAULT_TRANSPARENCY',	5);
+define('SVG_GRAPH_DEFAULT_FILL',			3);
 
 define('BR_DISTRIBUTION_MULTIPLE_PERIODS',	1);
 define('BR_DISTRIBUTION_MULTIPLE_ITEMS',	2);
@@ -1400,6 +1450,8 @@ define('API_UNEXPECTED',			51);
 define('API_INT32_RANGES',			53);
 define('API_LAT_LNG_ZOOM',			54);
 define('API_TIMESTAMP',				55);
+define('API_TG_NAME',				56);
+define('API_COLORS',				57);
 
 // flags
 define('API_REQUIRED',					0x00001);
@@ -1454,7 +1506,14 @@ define('ZBX_MAX_PORT_NUMBER', 65535);
 
 define('ZBX_MACRO_TYPE_TEXT', 0); // Display macro value as text.
 define('ZBX_MACRO_TYPE_SECRET', 1); // Display masked macro value.
-define('ZBX_MACRO_TYPE_VAULT', 2); // Display macro value as text (path to secret in HashiCorp Vault).
+define('ZBX_MACRO_TYPE_VAULT', 2); // Display macro value as text (path to secret in Vault).
+
+define('ZBX_USERMACRO_MANUAL', 0); // Macro value updated by user.
+define('ZBX_USERMACRO_AUTOMATIC', 1); // Macro value updated by discovery rule.
+
+define('ZBX_VAULT_TYPE_UNKNOWN', -1);
+define('ZBX_VAULT_TYPE_HASHICORP', 0);
+define('ZBX_VAULT_TYPE_CYBERARK',  1);
 
 define('ZBX_SECRET_MASK', '******'); // Placeholder for secret values.
 
@@ -1540,6 +1599,18 @@ define('WIDGET_ITEM',				'item');
 // Deprecated widgets
 define('WIDGET_DATA_OVER',			'dataover');
 
+// Clock widget type
+define('WIDGET_CLOCK_TYPE_ANALOG',	0);
+define('WIDGET_CLOCK_TYPE_DIGITAL',	1);
+
+// Clock time zone format
+define('WIDGET_CLOCK_TIMEZONE_SHORT',	0);
+define('WIDGET_CLOCK_TIMEZONE_FULL',	1);
+
+// Clock widget time format
+define('WIDGET_CLOCK_HOUR_TWENTY_FOUR',	0);
+define('WIDGET_CLOCK_HOUR_TWELVE',		1);
+
 // Item widget object positions.
 define('WIDGET_ITEM_POS_LEFT',		0);
 define('WIDGET_ITEM_POS_CENTER',	1);
@@ -1573,11 +1644,17 @@ define('WIDGET_HAT_EVENTLIST',			'hat_eventlist');
 define('WIDGET_SEARCH_HOSTS',			'search_hosts');
 define('WIDGET_SEARCH_HOSTGROUP',		'search_hostgroup');
 define('WIDGET_SEARCH_TEMPLATES',		'search_templates');
+define('WIDGET_SEARCH_TEMPLATEGROUP',	'search_templategroup');
 
 // dashboard widget dynamic state
 define('WIDGET_SIMPLE_ITEM',	0);
 define('WIDGET_DYNAMIC_ITEM',	1);
 
+// clock widget blocks
+define('WIDGET_CLOCK_SHOW_DATE', 1);
+define('WIDGET_CLOCK_SHOW_TIME', 2);
+define('WIDGET_CLOCK_SHOW_TIMEZONE', 3);
+
 // item widget blocks
 define('WIDGET_ITEM_SHOW_DESCRIPTION',		1);
 define('WIDGET_ITEM_SHOW_VALUE',			2);
@@ -1629,6 +1706,7 @@ define('ZBX_DEFAULT_LANG', 'en_US');
 
 // user default time zone
 define('TIMEZONE_DEFAULT', 'default');
+define('TIMEZONE_DEFAULT_LOCAL', 'local');
 
 // the default time zone
 define('ZBX_DEFAULT_TIMEZONE', 'system');
@@ -1657,9 +1735,10 @@ define('QUEUE_OVERVIEW_BY_PROXY', 1);
 define('QUEUE_DETAILS', 2);
 
 // target types to copy items/triggers/graphs
-define('COPY_TYPE_TO_HOST_GROUP',	0);
-define('COPY_TYPE_TO_HOST',			1);
-define('COPY_TYPE_TO_TEMPLATE',		2);
+define('COPY_TYPE_TO_HOST_GROUP',		0);
+define('COPY_TYPE_TO_HOST',				1);
+define('COPY_TYPE_TO_TEMPLATE',			2);
+define('COPY_TYPE_TO_TEMPLATE_GROUP',	3);
 
 define('HISTORY_GRAPH', 'showgraph');
 define('HISTORY_BATCH_GRAPH', 'batchgraph');
@@ -1693,7 +1772,7 @@ define('TAB_INDICATOR_FILTERS', 'filters');
 define('TAB_INDICATOR_FRONTEND_MESSAGE', 'frontend-message');
 define('TAB_INDICATOR_GRAPH_DATASET', 'graph-dataset');
 define('TAB_INDICATOR_GRAPH_LEGEND', 'graph-legend');
-define('TAB_INDICATOR_GRAPH_OPTIONS', 'graph-options');
+define('TAB_INDICATOR_GRAPH_DISPLAY_OPTIONS', 'graph-display-options');
 define('TAB_INDICATOR_GRAPH_OVERRIDES', 'graph-overrides');
 define('TAB_INDICATOR_GRAPH_PROBLEMS', 'graph-problems');
 define('TAB_INDICATOR_GRAPH_TIME', 'graph-time');
@@ -1705,8 +1784,10 @@ define('TAB_INDICATOR_MEDIA', 'media');
 define('TAB_INDICATOR_MESSAGE_TEMPLATE', 'message-template');
 define('TAB_INDICATOR_OPERATIONS', 'operations');
 define('TAB_INDICATOR_OVERRIDES', 'overrides');
-define('TAB_INDICATOR_PERMISSIONS', 'permissions');
+define('TAB_INDICATOR_HOST_PERMISSIONS', 'host-permissions');
+define('TAB_INDICATOR_TEMPLATE_PERMISSIONS', 'template-permissions');
 define('TAB_INDICATOR_PREPROCESSING', 'preprocessing');
+define('TAB_INDICATOR_PROXY_ENCRYPTION', 'proxy-encryption');
 define('TAB_INDICATOR_SHARING', 'sharing');
 define('TAB_INDICATOR_STEPS', 'steps');
 define('TAB_INDICATOR_TAG_FILTER', 'tag-filter');
@@ -1750,6 +1831,7 @@ define('ZBX_STYLE_BTN_KIOSK', 'btn-kiosk');
 define('ZBX_STYLE_BTN_MIN', 'btn-min');
 define('ZBX_STYLE_BTN_REMOVE', 'btn-remove');
 define('ZBX_STYLE_BTN_REMOVE_FAV', 'btn-remove-fav');
+define('ZBX_STYLE_BTN_TAG', 'btn-tag');
 define('ZBX_STYLE_BTN_TIME', 'btn-time');
 define('ZBX_STYLE_BTN_TIME_LEFT', 'btn-time-left');
 define('ZBX_STYLE_BTN_TIME_OUT', 'btn-time-out');
@@ -1858,6 +1940,7 @@ define('ZBX_STYLE_HOVER_NOBG', 'hover-nobg');
 define('ZBX_STYLE_HINTBOX_WRAP', 'hintbox-wrap');
 define('ZBX_STYLE_ICON_ACKN', 'icon-ackn');
 define('ZBX_STYLE_ICON_CAL', 'icon-cal');
+define('ZBX_STYLE_ICON_COUNT', 'icon-count');
 define('ZBX_STYLE_ICON_DEPEND_DOWN', 'icon-depend-down');
 define('ZBX_STYLE_ICON_DEPEND_UP', 'icon-depend-up');
 define('ZBX_STYLE_ICON_DESCRIPTION', 'icon-description');
@@ -1866,7 +1949,7 @@ define('ZBX_STYLE_ICON_INVISIBLE', 'icon-invisible');
 define('ZBX_STYLE_ICON_USER', 'icon-user');
 define('ZBX_STYLE_ICON_USER_GROUP', 'icon-user-group');
 define('ZBX_STYLE_ICON_MAINTENANCE', 'icon-maintenance');
-define('ZBX_STYLE_ICON_WZRD_ACTION', 'icon-wzrd-action');
+define('ZBX_STYLE_ICON_WIZARD_ACTION', 'icon-wizard-action');
 define('ZBX_STYLE_ACTION_COMMAND', 'icon-action-command');
 define('ZBX_STYLE_ACTION_ICON_CLOSE', 'icon-action-close');
 define('ZBX_STYLE_ACTION_ICON_MSG', 'icon-action-msg');
@@ -1877,6 +1960,8 @@ define('ZBX_STYLE_ACTION_ICON_SEV_CHANGED', 'icon-action-severity-changed');
 define('ZBX_STYLE_ACTION_MESSAGE', 'icon-action-message');
 define('ZBX_STYLE_ACTION_ICON_ACK', 'icon-action-ack');
 define('ZBX_STYLE_ACTION_ICON_UNACK', 'icon-action-unack');
+define('ZBX_STYLE_ACTION_ICON_SUPPRESS', 'icon-action-suppress');
+define('ZBX_STYLE_ACTION_ICON_UNSUPPRESS', 'icon-action-unsuppress');
 define('ZBX_STYLE_PROBLEM_GENERATED', 'icon-problem-generated');
 define('ZBX_STYLE_PROBLEM_RECOVERY', 'icon-problem-recovery');
 define('ZBX_STYLE_ACTIONS_NUM_GRAY', 'icon-actions-number-gray');
@@ -1908,6 +1993,7 @@ define('ZBX_STYLE_LIST_ACCORDION_ITEM_OPENED', 'list-accordion-item-opened');
 define('ZBX_STYLE_LIST_ACCORDION_ITEM_CLOSED', 'list-accordion-item-closed');
 define('ZBX_STYLE_LIST_ACCORDION_ITEM_HEAD', 'list-accordion-item-head');
 define('ZBX_STYLE_LIST_ACCORDION_ITEM_BODY', 'list-accordion-item-body');
+define('ZBX_STYLE_LIST_ACCORDION_ITEM_TOGGLE', 'list-accordion-item-toggle');
 define('ZBX_STYLE_LOCAL_CLOCK', 'local-clock');
 define('ZBX_STYLE_LOG_NA_BG', 'log-na-bg');
 define('ZBX_STYLE_LOG_INFO_BG', 'log-info-bg');
@@ -1973,6 +2059,10 @@ define('ZBX_STYLE_SIGNIN_CONTAINER', 'signin-container');
 define('ZBX_STYLE_SIGNIN_LINKS', 'signin-links');
 define('ZBX_STYLE_SIGNIN_LOGO', 'signin-logo');
 define('ZBX_STYLE_SIGN_IN_TXT', 'sign-in-txt');
+define('ZBX_STYLE_SORTABLE', 'sortable');
+define('ZBX_STYLE_SORTABLE_LIST', 'sortable-list');
+define('ZBX_STYLE_SORTABLE_ITEM', 'sortable-item');
+define('ZBX_STYLE_SORTABLE_DRAG_HANDLE', 'sortable-drag-handle');
 define('ZBX_STYLE_STATUS_AVERAGE_BG', 'status-average-bg');
 define('ZBX_STYLE_STATUS_CONTAINER', 'status-container');
 define('ZBX_STYLE_STATUS_DARK_GREY', 'status-dark-grey');
@@ -2041,8 +2131,13 @@ define('ZBX_STYLE_ZABBIX_LOGO', 'zabbix-logo');
 define('ZBX_STYLE_ZABBIX_SIDEBAR_LOGO', 'zabbix-sidebar-logo');
 define('ZBX_STYLE_ZABBIX_SIDEBAR_LOGO_COMPACT', 'zabbix-sidebar-logo-compact');
 define('ZBX_STYLE_WIDGET_ITEM_LABEL', 'widget-item-label');
+define('ZBX_STYLE_DEFAULT_OPTION', 'default-option');
 
 // HTML column layout.
+define('ZBX_STYLE_GRID_COLUMNS', 'grid-columns');
+define('ZBX_STYLE_GRID_COLUMNS_2', 'columns-2');
+define('ZBX_STYLE_GRID_COLUMNS_3', 'columns-3');
+
 define('ZBX_STYLE_COLUMNS', 'columns-wrapper');
 define('ZBX_STYLE_COLUMNS_NOWRAP', 'columns-nowrap');
 define('ZBX_STYLE_COLUMNS_2', 'columns-2');
@@ -2080,6 +2175,7 @@ define('ZBX_STYLE_CHECKBOX_BLOCK', 'checkbox-block');
 define('ZBX_STYLE_ICON_TEXT', 'icon-text');
 define('ZBX_STYLE_ICON_SECRET_TEXT', 'icon-secret');
 define('ZBX_STYLE_ICON_HELP_HINT', 'icon-help-hint');
+define('ZBX_STYLE_ICON_DOC_LINK', 'icon-doc-link');
 
 // Host interface styles.
 define('ZBX_STYLE_HOST_INTERFACE_CONTAINER', 'interface-container');
