@@ -24,7 +24,9 @@
  * @var array $data
  */
 
-$widget = (new CWidget())->setTitle(_('Items'));
+$widget = (new CWidget())
+	->setTitle(_('Items'))
+	->setDocUrl(CDocHelper::getUrl(CDocHelper::CONFIGURATION_ITEM_EDIT));
 
 $host = $data['host'];
 
@@ -581,7 +583,6 @@ $item_tab
 						'dstfld1' => 'master_itemid',
 						'hostid' => $data['hostid'],
 						'excludeids' => $data['itemid'] != 0 ? [$data['itemid']] : [],
-						'webitems' => true,
 						'normal_only' => true
 					]
 				]
@@ -607,6 +608,15 @@ if ($data['display_interfaces']) {
 					->setId('js-item-interface-field')
 			]);
 		}
+		else {
+			$item_tab->addItem([
+				(new CLabel(_('Host interface'), 'interface'))->setId('js-item-interface-label'),
+				(new CFormField(
+					(new CTextBox('interface', interfaceType2str(INTERFACE_TYPE_OPT), true))
+						->setAttribute('disabled', 'disabled')
+				))->setId('js-item-interface-field')
+			]);
+		}
 	}
 	else {
 		$select_interface = getInterfaceSelect($data['interfaces'])
@@ -616,6 +626,10 @@ if ($data['display_interfaces']) {
 			->setFocusableElementId('interfaceid')
 			->setAriaRequired();
 
+		if ($readonly) {
+			$select_interface->setAttribute('readonly', 'readonly');
+		}
+
 		$item_tab->addItem([
 			(new CLabel(_('Host interface'), $select_interface->getFocusableElementId()))
 				->setAsteriskMark()
@@ -632,7 +646,7 @@ if ($data['display_interfaces']) {
 	}
 }
 
-// Append SNMP common fields fields.
+// Append SNMP common fields.
 $item_tab->addItem([
 	(new CLabel(_('SNMP OID'), 'snmp_oid'))
 		->setAsteriskMark()
@@ -1054,11 +1068,12 @@ if ($data['itemid'] != 0) {
 	$buttons = [new CSubmit('clone', _('Clone'))];
 
 	if ($data['host']['status'] != HOST_STATUS_TEMPLATE) {
-		$buttons[] = (new CSubmit('check_now', _('Execute now')))
+		$buttons[] = (new CSimpleButton(_('Execute now')))
 			->setEnabled(in_array($data['item']['type'], checkNowAllowedTypes())
 					&& $data['item']['status'] == ITEM_STATUS_ACTIVE
 					&& $data['host']['status'] == HOST_STATUS_MONITORED
-			);
+			)
+			->onClick('view.checkNow(this);');
 	}
 
 	$buttons[] = (new CSimpleButton(_('Test')))->setId('test_item');
