@@ -533,7 +533,6 @@
 					dstfld1: 'items_' + i + '_itemid',
 					dstfld2: 'items_' + i + '_name',
 					numeric: 1,
-					with_webitems: 1,
 					writeonly: 1
 				};
 
@@ -682,7 +681,8 @@
 			const original_url = location.href;
 			const overlay = PopUp('popup.host.edit', host_data, {
 				dialogueid: 'host_edit',
-				dialogue_class: 'modal-popup-large'
+				dialogue_class: 'modal-popup-large',
+				prevent_navigation: true
 			});
 
 			overlay.$dialogue[0].addEventListener('dialogue.create', this.events.hostSuccess, {once: true});
